.. _auth:
.. currentmodule:: lyricsgenius.auth
.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Auth

Auth
====

OAuth2
------
You can use this class to authenticate yourself or
get URLs to redirect your users to and get them to
give your Genius app the premissions you need.
To find out more about how to use this class
visit the :ref:`snippets`.

.. autoclass:: OAuth2
   :members:
   :member-order: bysource
   :no-show-inheritance:
